declare enum VideoType {
    "vast" = 0,
    "vmap" = 1
}
type Classes = Array<string> | string;
type NativeAdClasses = {
    container?: Classes;
    textContainer?: Classes;
    image?: Classes;
    title?: Classes;
    content?: Classes;
};
interface AudioAdData {
    id: number;
    name: string;
    url: string;
    imageUrl?: string;
    audioUrl: string;
    campaign: number;
    impressionUrl?: string;
}
interface Lap {
    version: string;
    app: string;
    getVideoAd: (type: VideoType) => Promise<string>;
    getAudioAd: () => Promise<AudioAdData>;
    getInterstitialAd: () => Promise<void>;
}
interface LapOptions {
    interstitialInterval?: number;
    nativeAdClasses?: NativeAdClasses;
}
/**
 * Initialize the library.
 * @param app - The app name. You need to provide the exact same name that given to you by the Lap team.
 * @param options - The options object.
 */
export declare function init(app?: string, options?: LapOptions): Promise<Lap>;
export declare function getVideoAd(type?: VideoType, app?: string): Promise<string>;
export declare function getAudioAd(app?: string): Promise<AudioAdData>;
export declare function getInterstitialAd(app?: string): Promise<void>;
interface LapObject {
    version: string;
    init: (app: string, options: LapOptions) => Promise<Lap>;
    getVideoAd: (type: VideoType, app?: string) => Promise<string>;
    getAudioAd: (app?: string) => Promise<AudioAdData>;
    getInterstitialAd: (app?: string) => void;
}
declare const lapObject: LapObject;
export default lapObject;
